@@ -1,5 +1,9 @@
+//! 構文解析後のノードを定義
+
 use std::collections::HashMap;
 
+
+/// ノードの種類
 #[allow(dead_code)]
 #[derive(Debug,PartialEq,Clone,Copy)]
 pub enum NodeKind {
@@ -23,6 +27,7 @@ pub enum NodeKind {
     For,
 }
 
+/// ノード構造体
 #[derive(Debug, Clone)]
 pub struct Node {
     pub kind: NodeKind,
@@ -32,20 +37,21 @@ pub struct Node {
     pub fileno: u32,
 }
 impl Node {
+    /// ノードを文字列変換する
     pub fn to_string(&self) -> String {
         match self.kind {
             NodeKind::Nop => String::from("Nop"),
             NodeKind::NodeList => format!("NodeList:{}", self.value.to_string()),
-            NodeKind::Int => format!("Int:{}", self.value.to_int(0)),
-            NodeKind::Number => format!("Number:{}", self.value.to_float(0.0)),
-            NodeKind::Bool => format!("Bool:{}", self.value.to_string()),
+            NodeKind::Int => format!("I({})", self.value.to_int(0)),
+            NodeKind::Number => format!("F({})", self.value.to_float(0.0)),
+            NodeKind::Bool => format!("B({})", self.value.to_string()),
+            NodeKind::String => format!("\"{}\"", self.value.to_string()),
             NodeKind::Comment => format!("Comment:{}", self.value.to_string()),
             NodeKind::Let => format!("Let:{}", self.value.to_string()),
             NodeKind::GetVar => format!("{}", self.value.to_string()),
             NodeKind::Operator => format!("{}", self.value.to_string()),
-            NodeKind::String => format!("\"{}\"", self.value.to_string()),
-            NodeKind::CallSysFunc => format!("CallSys:{}", self.value.to_string()),
-            NodeKind::CallUserFunc => format!("CallUser:{}", self.value.to_string()),
+            NodeKind::CallSysFunc => format!("Sys:{}", self.value.to_string()),
+            NodeKind::CallUserFunc => format!("Usr:{}", self.value.to_string()),
             NodeKind::If => format!("If:{}", self.value.to_string()),
             NodeKind::Kai => format!("N回:{}", self.value.to_string()),
             NodeKind::Break => String::from("Break"),
@@ -104,6 +110,7 @@ impl Node {
 const FALSE_VALUE:isize = 0;
 const TRUE_VALUE:isize = 1;
 
+/// ノードの値を定義したもの
 #[derive(Debug,Clone)]
 pub enum NodeValue {
     Empty,
@@ -125,11 +132,11 @@ impl NodeValue {
             NodeValue::I(v) => format!("{}", v),
             NodeValue::F(v) => format!("{}", v),
             NodeValue::B(v) => if *v { String::from("真") } else { String::from("偽") },
-            NodeValue::LetVar(v) => format!("LetVar{}={:?}", v.var_name, v.value_node),
-            NodeValue::NodeList(nodes) => format!("NodeList:[{}]", nodes_to_string(&nodes, ",")),
-            NodeValue::Operator(op) => format!("{}[{}]", op.flag, nodes_to_string(&op.nodes, ",")),
-            NodeValue::GetVar(v) => format!("GetVar:{:?}({},{})", v.name.clone().unwrap_or(String::new()), v.level, v.no),
-            NodeValue::SysFunc(name, _, nodes) => format!("{}({})", name, nodes_to_string(&nodes, ",")),
+            NodeValue::LetVar(v) => format!("{}={}", v.var_info.name.clone().unwrap_or(String::new()), nodes_to_string(&v.value_node, ",")),
+            NodeValue::NodeList(nodes) => format!("[{}]", nodes_to_string(&nodes, ",")),
+            NodeValue::Operator(op) => format!("({})[{}]", op.flag, nodes_to_string(&op.nodes, ",")),
+            NodeValue::GetVar(v) => format!("{}", v.name.clone().unwrap_or(String::new())),
+            NodeValue::SysFunc(name, no, nodes) => format!("{}:{}({})", name, no, nodes_to_string(&nodes, ",")),
             // _ => String::from(""),
         }
     }
@@ -171,8 +178,8 @@ impl NodeValue {
     }
 }
 
+/// NodeValue 同士の計算を行うメソッドを定義
 impl NodeValue {
-    // calc method
     pub fn calc_plus(left: &NodeValue, right: &NodeValue) -> NodeValue {
         match (left, right) {
             // number
@@ -272,7 +279,7 @@ impl NodeValue {
 
 #[derive(Debug,Clone)]
 pub struct NodeValueLet {
-    pub var_name: String,
+    pub var_info: NodeVarInfo,
     pub value_node: Vec<Node>,
 }
 
@@ -439,7 +446,13 @@ pub enum NodeVarKind {
 pub fn nodes_to_string(nodes: &Vec<Node>, delimiter: &str) -> String {
     let mut r = String::new();
     for (i, node) in nodes.iter().enumerate() {
-        r.push_str(&node.to_string());
+        if delimiter.eq("\n") {
+            let line = format!("L{}: {}", &node.line, &node.to_string());
+            r.push_str(&line);
+        } else {
+            let line = format!("{}", &node.to_string());
+            r.push_str(&line);
+        }
         if i != (nodes.len() - 1) {
             r.push_str(delimiter);
         }
@@ -525,7 +538,14 @@ impl NodeContext {
         self.scopes.find_var(name)
     }
     pub fn get_var_value(&self, info: &NodeVarInfo) -> Option<NodeValue> {
-        self.scopes.get_var_value(info)
+        if info.level == 2 {
+            // local
+            let local: &NodeScope = self.scopes.scopes.last().unwrap();
+            Some(local.var_values[info.no].clone())
+        } else {
+            // system or global 
+            self.scopes.get_var_value(info)
+        }
     }
     #[allow(dead_code)]
     pub fn get_var_meta(&self, info: &NodeVarInfo) -> Option<NodeVarMeta> {
