@@ -1,8 +1,14 @@
+//! 演算子の優先順位を定義
+
 use crate::node::*;
 
-// @see https://github.com/kujirahand/nadesiko3/blob/a80fd6074dc171cfae41457d1cd4c390a5aa43a4/src/nako_parser_const.js
+//// 演算における値の優先順位
+const OP_PRIORITY_VALUE: i8 = 100;
+//// 演算における関数の優先順位
+const OP_PRIORTY_FUNCTION: i8 = 5;
 
-// 演算子の優先順位を定義
+/// 演算子の優先順位を定義
+// (memo) なでしこv3 オリジナルの優先順位 <https://github.com/kujirahand/nadesiko3/blob/a80fd6074dc171cfae41457d1cd4c390a5aa43a4/src/nako_parser_const.js>
 pub fn get_priority(c: char) -> i8 {
     match c {
         '(' => 60,
@@ -25,10 +31,11 @@ pub fn get_priority(c: char) -> i8 {
         // or and
         '&' => 10,
         '|' => 10,
-        _ => 127,
+        _ => OP_PRIORITY_VALUE,
     }
 }
 
+/// Nodeに対して優先順位を演算の取得する関数
 pub fn get_node_priority(node_v: &Node) -> i8 {
     match node_v.kind {
         NodeKind::Operator => {
@@ -36,16 +43,16 @@ pub fn get_node_priority(node_v: &Node) -> i8 {
                 NodeValue::Operator(op) => {
                     get_priority(op.flag)
                 },
-                _ => 127,
+                _ => OP_PRIORITY_VALUE,
             }
         },
-        NodeKind::Bool => 127,
-        NodeKind::Int => 127,
-        NodeKind::Number => 127,
-        NodeKind::String => 127,
-        NodeKind::GetVar => 127,
-        NodeKind::CallSysFunc => 5,
-        NodeKind::CallUserFunc => 5,
-        _ => 127,
+        NodeKind::Bool => OP_PRIORITY_VALUE,
+        NodeKind::Int => OP_PRIORITY_VALUE,
+        NodeKind::Number => OP_PRIORITY_VALUE,
+        NodeKind::String => OP_PRIORITY_VALUE,
+        NodeKind::GetVar => OP_PRIORITY_VALUE,
+        NodeKind::CallSysFunc => OP_PRIORTY_FUNCTION,
+        NodeKind::CallUserFunc => OP_PRIORTY_FUNCTION,
+        _ => OP_PRIORITY_VALUE,
     }
 }
