@@ -1,3 +1,5 @@
+//! 軸解析器
+
 use crate::prepare;
 use crate::strcur::StrCur;
 use crate::kanautils;
@@ -5,10 +7,38 @@ use crate::josi_list;
 use crate::reserved_words;
 use crate::token::*;
 
-// 文字列をトークンに区切る
+/// 文字列をトークンに区切る
 pub fn tokenize(src: &str) -> Vec<Token> {
-    tokenize_src(src, 0)
+    // 普通にトークンに区切る
+    let tok: Vec<Token> = tokenize_src(src, 1);
+    
+    // 助詞の「は」を＝に展開する
+    let mut last_is_eq = false;
+    let mut result: Vec<Token> = vec![];
+    for t in tok.into_iter() {
+        if last_is_eq {
+            last_is_eq = false;
+            if t.kind == TokenKind::Comma { continue; } // 「Aは,1」のような場合にカンマを飛ばす
+        }
+        match &t.josi {
+            Some(j) => {
+                let line = t.line;
+                if j.eq("は") {
+                    let mut t2 = t.clone();
+                    t2.josi = None;
+                    result.push(t2);
+                    result.push(Token::new_char(TokenKind::Eq, '=', line));
+                    last_is_eq = true;
+                    continue;
+                }    
+            }
+            None => {},
+        }
+        result.push(t);
+    }
+    result
 }
+
 pub fn tokenize_src(src: &str, line_begin: u32) -> Vec<Token> {
     let src = prepare::convert(src);
     let mut cur = StrCur::from(&src);
@@ -23,6 +53,7 @@ pub fn tokenize_src(src: &str, line_begin: u32) -> Vec<Token> {
             ',' => { flag_push(TokenKind::Comma, &mut result, &mut cur, line); continue; },
             '/' => { result.push(read_slash(&mut cur, &mut line)); continue; },
             '※' => { result.push(read_linecomment(&mut cur, &mut line)); continue; },
+            '#' => { result.push(read_linecomment(&mut cur, &mut line)); continue; },
             // 文字列記号
             '「' => { read_string(&mut result, &mut cur, &mut line, '」', true); continue; }
             '『' => { read_string(&mut result, &mut cur, &mut line, '』', false); continue; }
